@@ -1,4 +1,5 @@
-def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interfaces_and_types=False, print_width=120):
+def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interfaces_and_types=False, print_width=120,
+                 p=False):
     from collections import defaultdict
     if not categorize:
         return_list = []
@@ -75,11 +76,14 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interface
             checks_['iterable'] = False
         return_list.append([checks_])
 
-    from pprint import pprint
-    pprint(return_list, compact=True, width=print_width)
+    if p:
+        from pprint import pprint
+        pprint(return_list, compact=True, width=print_width)
+    else:
+        return return_list
 
 
-def two_way(operation, opposite=False, iterators=False, print_width=120):
+def two_way(operation, opposite=False, iterators=False, print_width=120, p=False):
     import warnings
     warnings.filterwarnings("ignore")
     import re, keyword
@@ -161,11 +165,14 @@ def two_way(operation, opposite=False, iterators=False, print_width=120):
                             succeeded[a].add(b)
                     except:
                         failed[a].add(b)
-    from pprint import pprint
-    pprint([{'succeeded': succeeded}], compact=True, width=print_width)
+    if p:
+        from pprint import pprint
+        pprint([{'succeeded': succeeded}], compact=True, width=print_width)
+    else:
+        return [{'succeeded': succeeded}]
 
 
-def operator_check(left_argument, right_argument, show_failed=False, print_width=120):
+def operator_check(left_argument, right_argument, show_failed=False, print_width=120, p=False):
     import warnings
     warnings.filterwarnings("ignore")
     failed = set()
@@ -185,19 +192,22 @@ def operator_check(left_argument, right_argument, show_failed=False, print_width
     returned_dictionary = {'succeeded': succeeded}
     if show_failed:
         returned_dictionary['failed'] = failed
-    from pprint import pprint
-    pprint(returned_dictionary, compact=True, width=print_width)
+    if p:
+        from pprint import pprint
+        pprint(returned_dictionary, compact=True, width=print_width)
+    else:
+        return returned_dictionary
 
 
 extended_builtins = ['Ellipsis', 'False', 'None', 'NotImplemented', 'True', 'abs', 'all', 'any',
-                     'ascii', 'bin', 'bool', 'breakpoint', 'bytearray', 'bytes', 'callable', 'chr',
+                     'ascii', 'bin', 'bool', 'bytearray', 'bytes', 'callable', 'chr',
                      'classmethod', 'compile', 'complex', 'delattr', 'dict',
-                     'dir', 'display', 'divmod', 'enumerate', 'eval', 'exec', 'execfile',
-                     'filter', 'float', 'format', 'frozenset', 'getattr', 'globals', 'hasattr',
-                     'hash', 'hex', 'id', 'input', 'int', 'isinstance', 'issubclass',
+                     'dir', 'divmod', 'enumerate', 'eval', 'exec',
+                     'filter', 'float', 'frozenset', 'getattr', 'globals', 'hasattr',
+                     'hash', 'hex', 'id', 'int', 'isinstance', 'issubclass',
                      'iter', 'len', 'list', 'locals', 'map', 'max', 'memoryview', 'min',
-                     'next', 'object', 'oct', 'open', 'ord', 'pow', 'print', 'property', 'range',
-                     'repr', 'reversed', 'round', 'runfile', 'set', 'setattr', 'slice', 'sorted',
+                     'next', 'object', 'oct', 'ord', 'pow', 'property', 'range',
+                     'repr', 'reversed', 'round', 'set', 'setattr', 'slice', 'sorted',
                      'staticmethod', 'str', 'sum', 'super', 'tuple', 'type', 'vars', 'zip',
                      "(iter(b''))", '(iter(bytearray()))', '(iter({}.keys()))',
                      '(iter({}.values()))', '(iter({}.items()))', '(iter([]))',
